@@ -39,6 +39,7 @@
 #include <KMimeTypeEditor>
 #include <KPluginMetaData>
 #include <KIO/JobUiDelegateFactory>
+#include <ki18n_version.h>
 
 #include <QIcon>
 #include <QFileInfo>
@@ -412,7 +413,7 @@ void KonqPopupMenuPrivate::populate()
 
     // CopyTo/MoveTo menus
     if (m_popupFlags & KonqPopupMenu::ShowUrlOperations &&
-            KConfigGroup(dolphin, "General").readEntry("ShowCopyMoveMenu", false)) {
+            KConfigGroup(dolphin, "ContextMenu").readEntry("ShowCopyMoveMenu", false)) {
 
         m_copyToMenu.setUrls(lstUrls);
         m_copyToMenu.setReadOnly(sMoving == false);
@@ -499,7 +500,7 @@ void KonqPopupMenuPrivate::slotPopupEmptyTrashBin()
 
 void KonqPopupMenuPrivate::slotConfigTrashBin()
 {
-    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell5 kcmtrash"));
+    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(QStringLiteral("kcmshell%1 kcm_trash").arg(KI18N_VERSION_MAJOR));
     job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_parentWidget));
     job->start();
 }
