@@ -32,15 +32,11 @@ public:
      * Note: If you pass a null KBookmarkOwner to the constructor, the
      * URLs are openend by QDesktopServices::openUrl and "Add Bookmark" is disabled.
      * @param parentMenu menu to be filled
-     * @param collec parent collection for the KActions.
      */
-    KonqBookmarkMenu(KBookmarkManager *mgr, KBookmarkOwner *owner, KBookmarkActionMenu *parentMenu, KActionCollection *collec)
+    KonqBookmarkMenu(KBookmarkManager *mgr, KBookmarkOwner *owner, KBookmarkActionMenu *parentMenu)
         : KBookmarkMenu(mgr, owner, parentMenu->menu())
     {
-        m_actionCollection = collec;
-#if QT_VERSION_MAJOR >= 6
         setBrowserMode(true);
-#endif
     }
     ~KonqBookmarkMenu() override
     {}
@@ -49,12 +45,8 @@ public:
      * Creates a bookmark submenu.
      * Only used internally and for bookmark toolbar.
      */
-    KonqBookmarkMenu(KBookmarkManager *mgr, KBookmarkOwner *owner, KBookmarkActionMenu *parentMenu, QString parentAddress, KActionCollection *collec)
-#if QT_VERSION_MAJOR < 6
+    KonqBookmarkMenu(KBookmarkManager *mgr, KBookmarkOwner *owner, KBookmarkActionMenu *parentMenu, QString parentAddress)
         : KBookmarkMenu(mgr, owner, parentMenu->menu(), parentAddress)
-#else
-        : KBookmarkMenu(mgr, owner, parentMenu->menu(), parentAddress), m_actionCollection(collec)
-#endif
     {
     }
 
@@ -62,9 +54,6 @@ protected:
     void refill() override;
     QAction *actionForBookmark(const KBookmark &bm) override;
     QMenu *contextMenu(QAction *action) override;
-#if QT_VERSION_MAJOR > 5
-        KActionCollection *m_actionCollection = nullptr;
-#endif
 };
 
 class KonqBookmarkContextMenu : public KBookmarkContextMenu
