@@ -36,11 +36,7 @@ bool CertificateErrorDialogManager::handleCertificateError(const QWebEngineCerti
     }
     bool ignore = userAlreadyChoseToIgnoreError(ce);
     if (ignore) {
-#if QT_VERSION_MAJOR < 6
-        ce.ignoreCertificateError();
-#else
         ce.acceptCertificate();
-#endif
     } else {
         ce.defer();
         QPointer<WebEnginePage> ptr(page);
@@ -54,11 +50,7 @@ bool CertificateErrorDialogManager::handleCertificateError(const QWebEngineCerti
 
 bool CertificateErrorDialogManager::userAlreadyChoseToIgnoreError(const QWebEngineCertificateError &ce)
 {
-#if QT_VERSION_MAJOR < 6
-    int error = static_cast<int>(ce.error());
-#else
     int error = static_cast<int>(ce.type());
-#endif
     QString url = ce.url().url();
     KConfigGroup grp(KSharedConfig::openConfig(), "CertificateExceptions");
     QList<int> exceptionsForUrl = grp.readEntry(url, QList<int>{});
@@ -126,11 +118,7 @@ void CertificateErrorDialogManager::applyUserChoice(WebEnginePartCertificateErro
     if (choice == WebEnginePartCertificateErrorDlg::UserChoice::DontIgnoreError) {
         error.rejectCertificate();
     } else {
-#if QT_VERSION_MAJOR < 6
-        error.ignoreCertificateError();
-#else
         error.acceptCertificate();
-#endif
         if (choice == WebEnginePartCertificateErrorDlg::UserChoice::IgnoreErrorForever) {
             recordIgnoreForeverChoice(error);
         }
@@ -165,11 +153,7 @@ void CertificateErrorDialogManager::recordIgnoreForeverChoice(const QWebEngineCe
 {
     KConfigGroup grp(KSharedConfig::openConfig(), "CertificateExceptions");
     QString url = ce.url().url();
-#if QT_VERSION_MAJOR < 6
-    int error = ce.error();
-#else
     int error = ce.type();
-#endif
     QList<int> exceptionsForUrl = grp.readEntry(url, QList<int>{});
     exceptionsForUrl.append(error);
     grp.writeEntry(url, exceptionsForUrl);
