@@ -96,9 +96,6 @@ public:
     bool m_accessKeysEnabled : 1;
     bool m_zoomTextOnly : 1;
     bool m_useCookieJar : 1;
-#ifndef MANAGE_COOKIES_INTERNALLY
-    bool m_acceptCrossDomainCookies : 1;
-#endif
     bool m_bAutoRefreshPage: 1;
     bool m_bEnableFavicon:1;
     bool m_disableInternalPluginHandling:1;
@@ -123,6 +120,8 @@ public:
 
     QString m_encoding;
     QString m_userSheet;
+    QColor m_customBackgroundColor;
+    bool m_addCustomBackgroundColorToStyleSheet;
 
     QColor m_textColor;
     QColor m_baseColor;
@@ -500,6 +499,14 @@ void WebEngineSettings::init( KConfig * config, bool reset )
         d->m_userSheet.clear();
     }
 
+    if (reset || !cgHtml.readEntry("UseCustomBackground", false)) {
+        d->m_customBackgroundColor = QColor(Qt::white);
+        d->m_addCustomBackgroundColorToStyleSheet = false;
+    } else {
+        d->m_customBackgroundColor = cgHtml.readEntry("CustomBackgrundColor", QColor(Qt::white));
+        d->m_addCustomBackgroundColorToStyleSheet = cgHtml.readEntry("AddCustomBackgroundToStyleSheet", false);
+    }
+
     if (reset || cgHtml.hasKey("InternalPdfViewer")) {
         d->m_internalPdfViewer = cgHtml.readEntry("InternalPdfViewer", false);
     }
@@ -735,6 +742,15 @@ void WebEngineSettings::init( KConfig * config, bool reset )
 
 }
 
+QColor WebEngineSettings::customBackgroundColor() const
+{
+    return d->m_customBackgroundColor;
+}
+
+bool WebEngineSettings::addCustomBackgroundColorToStyleSheet() const
+{
+    return d->m_addCustomBackgroundColorToStyleSheet;
+}
 
 void WebEngineSettings::computeFontSizes( int logicalDpi )
 {
@@ -1183,18 +1199,6 @@ bool WebEngineSettings::jsPopupBlockerPassivePopup() const
     return d->m_jsPopupBlockerPassivePopup;
 }
 
-#ifndef MANAGE_COOKIES_INTERNALLY
-bool WebEngineSettings::isCookieJarEnabled() const
-{
-    return d->m_useCookieJar;
-}
-
-bool WebEngineSettings::acceptCrossDomainCookies() const
-{
-    return d->m_acceptCrossDomainCookies;
-}
-#endif
-
 // Password storage...
 KConfigGroup WebEngineSettings::nonPasswordStorableSitesCg() const
 {
@@ -1320,9 +1324,6 @@ void WebEngineSettings::initCookieJarSettings()
     KSharedConfig::Ptr cookieCfgPtr = KSharedConfig::openConfig(QStringLiteral("kcookiejarrc"), KConfig::NoGlobals);
     KConfigGroup cookieCfg ( cookieCfgPtr, "Cookie Policy");
     d->m_useCookieJar = cookieCfg.readEntry("Cookies", false);
-#ifndef MANAGE_COOKIES_INTERNALLY
-    d->m_acceptCrossDomainCookies = !cookieCfg.readEntry("RejectCrossDomainCookies", true);
-#endif
 }
 
 void WebEngineSettings::initNSPluginSettings()
