@@ -33,6 +33,7 @@
 #include "webenginepartdownloadmanager.h"
 #include "webenginepartcontrols.h"
 #include "profile.h"
+#include "actondownloadedfilebar.h"
 
 #include "ui/searchbar.h"
 #include "ui/passwordbar.h"
@@ -73,9 +74,9 @@
 #include <QStatusBar>
 #include <QWebEngineScriptCollection>
 #include <QDir>
-#if QT_VERSION_MAJOR > 5
 #include <QWebEngineFindTextResult>
-#endif
+#include <QMimeDatabase>
+#include <QTimer>
 
 #include "utils.h"
 #include <kio_version.h>
@@ -85,11 +86,7 @@ using namespace WebEngine;
 WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
                          const KPluginMetaData& metaData,
                          const QByteArray& cachedHistory, const QStringList& /*args*/)
-#if QT_VERSION_MAJOR < 6
-            :KParts::ReadOnlyPart(parent),
-#else
             :KParts::ReadOnlyPart(parent, metaData),
-#endif
              m_emitOpenUrlNotify(true),
              m_walletData{false, false, false},
              m_doLoadFinishedActions(false),
@@ -105,20 +102,6 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
 
     connect(WebEnginePartControls::self(), &WebEnginePartControls::userAgentChanged, this, &WebEnginePart::reloadAfterUAChange);
 
-#if QT_VERSION_MAJOR < 6
-    setMetaData(metaData);
-#endif
-
-#if 0
-    // NOTE: If the application does not set its version number, we automatically
-    // set it to KDE's version number so that the default user-agent string contains
-    // proper application version number information. See QWebEnginePage::userAgentForUrl...
-    if (QCoreApplication::applicationVersion().isEmpty())
-        QCoreApplication::setApplicationVersion(QString("%1.%2.%3")
-                                                .arg(KDE::versionMajor())
-                                                .arg(KDE::versionMinor())
-                                                .arg(KDE::versionRelease()));
-#endif
     setXMLFile(QL1S("webenginepart.rc"));
 
     // Create this KPart's widget
@@ -302,6 +285,7 @@ void WebEnginePart::connectWebEnginePageSignals(WebEnginePage* page)
 
     connect(page, &QWebEnginePage::loadStarted, this, &WebEnginePart::slotLoadStarted);
     connect(page, &WebEnginePage::loadAborted, this, &WebEnginePart::slotLoadAborted);
+    connect(page, &WebEnginePage::mainFrameNavigationRequested, this, &WebEnginePart::recordNavigationAccepted);
     connect(page, &QWebEnginePage::linkHovered, this, &WebEnginePart::slotLinkHovered);
     connect(page, &QWebEnginePage::windowCloseRequested, this, &WebEnginePart::slotWindowCloseRequested);
     connect(page, &QWebEnginePage::loadProgress, m_browserExtension, &KParts::NavigationExtension::loadingProgress);
@@ -471,10 +455,18 @@ void WebEnginePart::slotLoadStarted()
     m_emitOpenUrlNotify = true;
 }
 
+void WebEnginePart::recordNavigationAccepted(WebEnginePage* page, const QUrl& url)
+{
+    Q_UNUSED(page);
+    m_lastRequestedUrl = url;
+}
+
 void WebEnginePart::slotLoadFinished (bool ok)
 {
-    if (!ok || !m_doLoadFinishedActions)
+    if (!ok || !m_doLoadFinishedActions) {
+        m_lastRequestedUrl.clear();
         return;
+    }
 
     resetWallet();
     m_doLoadFinishedActions = false;
@@ -493,6 +485,10 @@ void WebEnginePart::slotLoadFinished (bool ok)
         slotUrlChanged(url);
     }
 
+    //WARNING: only call this after the if block above, otherwise in case slotUrlChanged is
+    //called, it'll call slotLoadStarted even if it shouldn't
+    m_lastRequestedUrl.clear();
+
     if (m_wallet) {
         m_wallet->detectAndFillPageForms(page());
     }
@@ -520,6 +516,12 @@ void WebEnginePart::slotLoadAborted(const QUrl & url)
 
 void WebEnginePart::slotUrlChanged(const QUrl& url)
 {
+    //Don't call slotLoadStarted if only the fragments are different
+    if (!m_lastRequestedUrl.matches(url, QUrl::RemoveFragment)) {
+        m_browserExtension->withHistoryWorkaround([this]{slotLoadStarted();});
+    }
+    m_lastRequestedUrl.clear();
+
     // Ignore if empty
     if (url.isEmpty())
         return;
@@ -703,11 +705,7 @@ void WebEnginePart::slotSearchForText(const QString &text, bool backward)
         flags |= QWebEnginePage::FindCaseSensitively;
     }
 
-#if QT_VERSION_MAJOR < 6
-    auto callback = [this](bool found){m_searchBar->setFoundMatch(found);};
-#else
     auto callback = [this](const QWebEngineFindTextResult &res){m_searchBar->setFoundMatch(res.numberOfMatches() > 0);};
-#endif
     //qCDebug(WEBENGINEPART_LOG) << "search for text:" << text << ", backward ?" << backward;
     //TODO KF6: when dropping compatibility with KF5, see whether it's better to connect to the
     //QWebEnginePage::findTextFinished signal rather than using the callback
@@ -1110,14 +1108,29 @@ void WebEnginePart::reloadAfterUAChange(const QString &)
     }
 }
 
-#if QT_VERSION_MAJOR < 6
-KParts::NavigationExtension* WebEnginePart::navigationExtension() const
-{
-    return browserExtension();
-}
-#endif
-
 BrowserExtension *WebEnginePart::browserExtension() const
 {
     return findChild<BrowserExtension *>();
 }
+
+void WebEnginePart::displayActOnDownloadedFileBar(KonqInterfaces::DownloaderJob* job)
+{
+    if (job->error() != 0) {
+        return;
+    }
+    if (m_actOnDownloadedFileWidget) {
+        widget()->layout()->removeWidget(m_actOnDownloadedFileWidget);
+        m_actOnDownloadedFileWidget->hide();
+        m_actOnDownloadedFileWidget->deleteLater();
+        m_actOnDownloadedFileWidget = nullptr;
+    }
+    m_actOnDownloadedFileWidget = new ActOnDownloadedFileBar(job->url(), QUrl::fromLocalFile(job->downloadPath()), this);
+    auto deleteWidget = [this] {
+        if (!m_actOnDownloadedFileWidget) {
+            return;
+        }
+        m_actOnDownloadedFileWidget->deleteLater();
+    };
+    connect(m_actOnDownloadedFileWidget, &ActOnDownloadedFileBar::hideAnimationFinished, this, [deleteWidget]{deleteWidget();});
+    widget()->layout()->addWidget(m_actOnDownloadedFileWidget);
+}
