@@ -164,9 +164,7 @@ void WebEnginePartControls::setup(KonqWebEnginePart::Profile* profile)
     Browser *browser = Browser::browser(qApp);
     if (browser) {
         m_profile->setHttpUserAgent(browser->userAgent());
-#ifdef MANAGE_COOKIES_INTERNALLY
         browser->setCookieJar(m_cookieJar);
-#endif
     }
     m_spellCheckerManager = new SpellCheckerManager(profile, this);
     m_downloadManager= new WebEnginePartDownloadManager(profile, this);
@@ -249,16 +247,13 @@ void WebEnginePartControls::reparseConfiguration()
         m_profile->setHttpCacheType(QWebEngineProfile::NoCache);
     }
 
+    emit updateBackgroundColor(WebEngineSettings::self()->customBackgroundColor());
     updateUserStyleSheetScript();
 }
 
 void WebEnginePartControls::updateUserStyleSheetScript()
 {
-#if QT_VERSION_MAJOR < 6
-    QList<QWebEngineScript> oldScripts = m_profile->scripts()->findScripts(s_userStyleSheetScriptName);
-#else
     QList<QWebEngineScript> oldScripts = m_profile->scripts()->find(s_userStyleSheetScriptName);
-#endif
     bool hadUserStyleSheet = !oldScripts.isEmpty();
     //Remove old style sheets. Note that oldScripts should either be empty or contain only one element
     //In theory, we could reuse the previous script, if it turns out to be the same as the new one, but
@@ -268,7 +263,7 @@ void WebEnginePartControls::updateUserStyleSheetScript()
     }
     QUrl userStyleSheetUrl(WebEngineSettings::self()->userStyleSheet());
     bool userStyleSheetEnabled = !userStyleSheetUrl.isEmpty();
-    //If the user stylesheet is disable and it was already disabled, there's nothing to do; if there was a custom stylesheet in use,
+    //If the user stylesheet is disabled and it was already disabled, there's nothing to do; if there was a custom stylesheet in use,
     //we'll have to remove it, so we can't return
     if (!userStyleSheetEnabled && !hadUserStyleSheet) {
         return;
@@ -292,6 +287,12 @@ void WebEnginePartControls::updateUserStyleSheetScript()
             }
             userStyleSheetEnabled = false;
         }
+
+        if (WebEngineSettings::self()->addCustomBackgroundColorToStyleSheet()) {
+            QColor color = WebEngineSettings::self()->customBackgroundColor();
+            QString backgroundRule = QString("* {background-color: rgb(%1, %2, %3);}\n").arg(color.red()).arg(color.green()).arg(color.blue());
+            css.prepend(backgroundRule);
+        }
     }
 
     //Create the js code
